NonIdentity

Struct NonIdentity 

#[repr(transparent)]
pub struct NonIdentity<P> { point: P, }
Non-identity point type.

This type ensures that its value is not the identity point, ala core::num::NonZero*.

In the context of ECC, it’s useful for ensuring that certain arithmetic cannot result in the identity point.

Fields

point: P

Implementations

Source

impl<P> NonIdentity<P>

pub fn new(point: P) -> CtOption<Self>

Create a NonIdentity from a point.

pub(crate) fn new_unchecked(point: P) -> Self

Source

impl<P> NonIdentity<P>

pub fn from_repr(repr: &P::Repr) -> CtOption<Self>

Decode a NonIdentity from its encoding.

Source

impl<P> NonIdentity<P>

pub fn array_as_inner<const N: usize>(points: &[Self; N]) -> &[P; N]

Transform array reference containing NonIdentity points to an array reference to the inner point type.

pub fn slice_as_inner(points: &[Self]) -> &[P]

Transform slice containing NonIdentity points to a slice of the inner point type.

pub fn cast_array_as_inner<const N: usize>(points: &[Self; N]) -> &[P; N]

👎Deprecated since 0.14.0: use NonIdentity::array_as_inner instead

Transform array reference containing NonIdentity points to an array reference to the inner point type.

pub fn cast_slice_as_inner(points: &[Self]) -> &[P]

👎Deprecated since 0.14.0: use NonIdentity::slice_as_inner instead

Transform slice containing NonIdentity points to a slice of the inner point type.

Source

impl<P: Copy> NonIdentity<P>

pub fn to_point(self) -> P

Return wrapped point.

Source

impl<P> NonIdentity<P>

pub fn random<R: CryptoRng + ?Sized>(rng: &mut R) -> Self

👎Deprecated since 0.14.0: use the Generate trait instead

Generate a random NonIdentity<ProjectivePoint>.

pub fn to_affine(self) -> NonIdentity<P::Affine>

Converts this element into its affine representation.

pub fn mul_by_generator<C: CurveArithmetic>(scalar: &NonZeroScalar<C>) -> Self
where P: Group<Scalar = C::Scalar>,

Multiply by the generator of the prime-order subgroup.

Source

impl<P> NonIdentity<P>

pub fn to_curve(self) -> NonIdentity<P::Curve>

Converts this element to its curve representation.