#[repr(transparent)]pub struct NonIdentity<P> {
point: P,
}Expand description
Non-identity point type.
This type ensures that its value is not the identity point, ala core::num::NonZero*.
In the context of ECC, it’s useful for ensuring that certain arithmetic cannot result in the identity point.
Fields
point: PImplementations
Sourceimpl<P> NonIdentity<P>
impl<P> NonIdentity<P>
Sourcepub fn new(point: P) -> CtOption<Self>
pub fn new(point: P) -> CtOption<Self>
Create a NonIdentity from a point.
pub(crate) fn new_unchecked(point: P) -> Self
Sourceimpl<P> NonIdentity<P>
impl<P> NonIdentity<P>
Sourcepub fn from_repr(repr: &P::Repr) -> CtOption<Self>
pub fn from_repr(repr: &P::Repr) -> CtOption<Self>
Decode a NonIdentity from its encoding.
Sourceimpl<P> NonIdentity<P>
impl<P> NonIdentity<P>
Sourcepub fn array_as_inner<const N: usize>(points: &[Self; N]) -> &[P; N]
pub fn array_as_inner<const N: usize>(points: &[Self; N]) -> &[P; N]
Transform array reference containing NonIdentity points to an array reference to the
inner point type.
Sourcepub fn slice_as_inner(points: &[Self]) -> &[P]
pub fn slice_as_inner(points: &[Self]) -> &[P]
Transform slice containing NonIdentity points to a slice of the inner point type.
Sourcepub fn cast_array_as_inner<const N: usize>(points: &[Self; N]) -> &[P; N]
👎Deprecated since 0.14.0: use NonIdentity::array_as_inner instead
pub fn cast_array_as_inner<const N: usize>(points: &[Self; N]) -> &[P; N]
NonIdentity::array_as_inner insteadTransform array reference containing NonIdentity points to an array reference to the
inner point type.
Sourcepub fn cast_slice_as_inner(points: &[Self]) -> &[P]
👎Deprecated since 0.14.0: use NonIdentity::slice_as_inner instead
pub fn cast_slice_as_inner(points: &[Self]) -> &[P]
NonIdentity::slice_as_inner insteadTransform slice containing NonIdentity points to a slice of the inner point type.
Sourceimpl<P> NonIdentity<P>
impl<P> NonIdentity<P>
Sourcepub fn random<R: CryptoRng + ?Sized>(rng: &mut R) -> Self
👎Deprecated since 0.14.0: use the Generate trait instead
pub fn random<R: CryptoRng + ?Sized>(rng: &mut R) -> Self
Generate trait insteadGenerate a random NonIdentity<ProjectivePoint>.
Sourcepub fn to_affine(self) -> NonIdentity<P::Affine>
pub fn to_affine(self) -> NonIdentity<P::Affine>
Converts this element into its affine representation.
Sourcepub fn mul_by_generator<C: CurveArithmetic>(scalar: &NonZeroScalar<C>) -> Self
pub fn mul_by_generator<C: CurveArithmetic>(scalar: &NonZeroScalar<C>) -> Self
Multiply by the generator of the prime-order subgroup.
Sourceimpl<P> NonIdentity<P>where
P: PrimeCurveAffine,
impl<P> NonIdentity<P>where
P: PrimeCurveAffine,
Sourcepub fn to_curve(self) -> NonIdentity<P::Curve>
pub fn to_curve(self) -> NonIdentity<P::Curve>
Converts this element to its curve representation.